chimney-resources 0.1.0

FHIR resources for chimney
docs.rs failed to build chimney-resources-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.

Generate models on cargo build

set OUT_DIR environment variable to the directory where you want to generate the models

OUT_DIR=./src cargo build -vv --timings
OUT_DIR=./resources; cargo build --release -vv --timings -j 2